@@ -1,7 +1,9 @@
+use 5.008;
+
 package Business::ISMN::Data;
 use strict;
 
-our $VERSION  = '1.132';
+our $VERSION  = '1.205';
 
 =encoding utf8
 
@@ -19,11 +21,11 @@ See L<Business::ISMN>.
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2005-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2005-2025, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
